@@ -112,7 +112,8 @@ L<URI::Escape>, L<HTML::Entities>, and L<LWP::UserAgent>.
 
 =over 4
 
-=item B<new>(I<ID>|I<url> [, I<-keep> => I<streamtypes>] [, I<-secure> [ => 0|1 ]] 
+=item B<new>(I<ID>|I<url> [, I<-keep> => I<streamtypes>] 
+[, "-quality" => I<quality>] [, I<-secure> [ => 0|1 ]] 
 [, I<-debug> [ => 0|1|2 ]])
 
 Accepts a rumble.com video ID or URL and creates and returns a new video object, 
@@ -122,14 +123,20 @@ https://rumble.com/c/B<channel-id>, https://rumble.com/embed/B<video-id>
 or just B<video-id> or B<channel-id>.  If a I<channel-id> or channel URL is 
 given, then the first (latest) video of that channel will be returned.
 
-I<-keep> specifies a list of one or more I<streamtypes> to include.  The list 
-can be either a comma-separated string or an array reference ([...]) of stream 
-types, in the order they should be returned.  Each stream type in the list can 
-be one of:  I<any>, I<mp4>, or I<webm>.
+The optional I<-keep> argument specifies a list of one or more I<streamtypes> 
+to include.  The list can be either a comma-separated string or an array 
+reference ([...]) of stream types, in the order they should be returned.  
+Each stream type in the list can be one of:  I<any>, I<mp4>, or I<webm>.
 
 DEFAULT I<-keep> list is 'mp4, webm, any', meaning that all mp4 streams 
 followed by all webm streams, then all of any others found.
 
+The optional I<-quality> argument, which can be set to a "p number".  
+This limits the video quality.. For example:  "720" would mean select 
+a stream "<= 720p".  
+
+DEFAULT I<-quality> is accept streams without resolution limit.
+
 The optional I<-secure> argument can be either 0 or 1 (I<false> or I<true>).  
 If 1 then only secure ("https://") streams will be returned.
 
@@ -381,6 +388,9 @@ sub new
 				my $keeporder = shift;
 				@okStreams = (ref($keeporder) =~ /ARRAY/) ? @{$keeporder} : split(/\,\s*/, $keeporder);
 			}
+		} elsif ($_[0] =~ /^\-?quality$/o) {
+			shift;
+			$self->{'quality'} = (defined $_[0]) ? shift : 0;
 		} else {
 			shift;
 		}
@@ -389,6 +399,7 @@ sub new
 		@okStreams = (ref($self->{'keep'}) =~ /ARRAY/) ? @{$self->{'keep'}} : split(/\,\s*/, $self->{'keep'});
 	}
 	@okStreams = (qw(mp4 webm any))  unless (defined $okStreams[0]);
+	$self->{'quality'} = 32767  unless (defined($self->{'quality'}) && $self->{'quality'} =~ /^[0-9]+$/);
 
 	my $ua = LWP::UserAgent->new(@{$self->{'_userAgentOps'}});		
 	$ua->timeout($self->{'timeout'});
@@ -515,19 +526,22 @@ sub new
 			my %streamsets;
 			#PARSE OUT ALL STREAMS (CLASS IS EITHER "mp4", "webm", "###" (RESOLUTION) OR OTHER.
 			#SINCE THE STREAMS OF EACH RESOLUTION ARE OFTEN REPEATED UNDER "mp4", "webm", or "<other>"
-			#BASED ON THEIR EXTENSION, WE CONVERT THE NON-RESOLUTION ONES TO VERY LOW NUMBERS
+			#BASED ON THEIR EXTENSION, WE CONVERT THE NON-RESOLUTION ONES TO VERY LOW NUMBERS (<=30)
 			#IN ORDER FOR THEM TO BE SORTED LAST (FOR GIVEN CLASS, WE WANT HIGHEST RESOLUTIONS FIRST!:
+			my $lowclass;
 			while ($html =~ s#\"(\w+)\"\:\{\"url\"\:\"([^\"]+)\"##s) {
+				$lowclass = 30;
 				my ($class, $stream) = ($1, $2);
-				if ($class =~ /mp4/io) {
-					$class = 30;
-				} elsif ($class =~ /webm/io) {
-					$class = 20;
-				} elsif ($class =~ /\D/io) {
-					$class = 10;
+				for (my $i=0;$i<=$#okStreams;$i++) {
+					if ($class =~ /$okStreams[$i]/) {
+						$class = $lowclass;
+						$lowclass -= 1;
+					}
 				}
+				$class = 1  if ($lowclass == 30 && $class =~ /\D/io);
 				push @{$streamsets{$class}}, $stream;
 			}
+			print STDERR "--Max resolution=".$self->{'quality'}."=\n";
 			my %streamHash;  #USE THIS HASH TO PREVENT ANY DUPLICATE STREAM URLS:
 			foreach my $streamtype (@okStreams) {
 				print STDERR "\n--keep type=$streamtype:\n"  if ($DEBUG);
@@ -537,7 +551,8 @@ sub new
 						if ($streamtype =~ /^any/io || $stream =~ /${streamtype}$/i) {
 							print STDERR "------found stream=$stream=\n"  if ($DEBUG);
 							unless (defined $streamHash{$stream}
-									|| ($self->{'secure'} && $stream !~ /^https/o)) {
+									|| ($self->{'secure'} && $stream !~ /^https/o)
+									|| $class > $self->{'quality'}) {
 								push @{$self->{'streams'}}, $stream;
 								$streamHash{$stream} = $stream;
 							}
