@@ -138,15 +138,15 @@ not a youtube-supported video URL or no streams are found.  The URL can
 be the full URL, 
 ie. https://www.youtube.com/watch?v=B<video-id>, a user or channel URL, 
 ie. https://www.youtube.com/channel/B<channel-id> or 
-https://www.youtube.com/user/B<user-id>. or just I<video-id> 
+https://www.youtube.com/user/B<user-id>. or just B<video-id> 
 (if the site is www.youtube.com, since YouTube has multiple sites).
-If a I<channel-id>, I<user-id>, or channel/user URL is 
+If a I<channel-id>, I<user-id>, or a Youtube channel/user URL is 
 given, then the first (latest) video uploaded to that channel will be 
 returned.  Note:  Some users and channels have a "featured" video (shown 
 with a larger thumbnail at the top) or multiple groupings of videos, but 
 the "first" video returned will normally be from the "Uploads" group.  
 Channels and users' urls must currently be specified as full URLs, as 
-just specifying an ID will be interpreted as a specific <video-id>!
+just specifying an ID will be interpreted as a specific B<video-id>!
 
 If I<-format> is specified, it should be a valid "I<youtube-dl -f>" format 
 string (see the youtube-dl manpage for details).  Examples:  
